pub struct ActionLayout {
pub width: usize,
}Expand description
The number of native Workshop actions emitted by a canonical WIR action sequence.
Fields
width: usizeThe action count in the canonical native action stream.