#[non_exhaustive]pub struct SignatureParam {
pub name: String,
pub param_type: Option<String>,
pub domain: Option<String>,
pub default: Option<String>,
}Expand description
One parameter of a Signature.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringThe semantic parameter name, or the catalog parameter name.
param_type: Option<String>The source-backed semantic type, when declared.
domain: Option<String>The canonical enum domain expected at this position, when declared.
default: Option<String>The declared default applied when the argument is omitted. None
marks a parameter with no declared default; a declared default before
another required position does not make this position omittable (see
Signature::required_params).