pub fn inspect(program: &Program, catalog: &Catalog) -> Vec<SemanticIssue>Expand description
Report preserved or catalog-unknown constructs that must not be treated as fully understood by downstream analysis.
pub fn inspect(program: &Program, catalog: &Catalog) -> Vec<SemanticIssue>Report preserved or catalog-unknown constructs that must not be treated as fully understood by downstream analysis.