pub fn definition(path: &[PathPart<'_>]) -> Option<SettingDefinition>Expand description
Project one reviewed table entry into the canonical semantic definition.
pub fn definition(path: &[PathPart<'_>]) -> Option<SettingDefinition>Project one reviewed table entry into the canonical semantic definition.