Module source

Module source 

Compatibility path for shared source and span types.

Structs

Position
A 1-based line/column position in a source file.
SourceComment
A source comment retained from the authored document.
SourceDocument
A source document retained independently from canonical semantic nodes.
SourceEdit
A checked, byte-oriented source replacement.
SourceFile
One source file in the program’s file registry.
Span
A half-open, 1-based source interval in one file.

Enums

CommentKind
Comment kinds currently supported by the raw Workshop source contract.
SourceEditError
Failure while creating or applying source edits.

Type Aliases

FileId
A typed ID referencing a SourceFile in the program’s file arena.