pub struct SourceFile {
pub path: String,
/* private fields */
}Expand description
One source file in the program’s file registry.
Fields
path: StringThe file name as the frontend reported it (for diagnostics).
Implementations
Sourceimpl SourceFile
impl SourceFile
Sourcepub fn with_source(path: impl Into<String>, source: impl Into<String>) -> Self
pub fn with_source(path: impl Into<String>, source: impl Into<String>) -> Self
Create a file entry that retains its authored source text and comments.
Sourcepub fn set_source(&mut self, source: impl Into<String>)
pub fn set_source(&mut self, source: impl Into<String>)
Attach authored source to an existing file entry.
Sourcepub fn source(&self) -> Option<&SourceDocument>
pub fn source(&self) -> Option<&SourceDocument>
The retained authored source, when this file was created source-aware.