Canonical Workshop program concepts.
Structs
- Condition
- A rule condition. Conditions remain distinct from general value expressions.
- Program
- A complete Workshop program built from Workshop concepts.
- Rule
- A Workshop rule with explicit conditions and a linear action stream.
- Subroutine
- A Workshop subroutine declaration.
- Variable
- A Workshop global or player variable declaration.
Enums
- Action
- A Workshop action line. Control flow is represented in the same order as
the Workshop source, including its explicit
Endlines. - Event
- A Workshop event identity and its native filters.
- Event
Target - Event
Team - Modify
Op - The operation used by a Workshop variable modification action.
- Player
Event Kind - Value
- A composable Workshop value expression.