Action

Enum Action 

pub enum Action {
Show 15 variants SetGlobalVariable { variable: String, value: Value, }, ModifyGlobalVariable { variable: String, op: ModifyOp, value: Value, }, SetPlayerVariable { player: Value, variable: String, value: Value, }, ModifyPlayerVariable { player: Value, variable: String, op: ModifyOp, value: Value, }, AssignMember { target: Value, op: Option<ModifyOp>, value: Value, }, CallSubroutine { subroutine: String, }, If { condition: Value, }, ElseIf { condition: Value, }, Else, While { condition: Value, }, ForGlobalVariable { variable: String, start: Value, stop: Value, step: Value, }, ForPlayerVariable { player: Value, variable: String, start: Value, stop: Value, step: Value, }, End, Disabled { action: Box<Action>, }, Call { name: String, args: Vec<Value>, },
}
A Workshop action line. Control flow is represented in the same order as the Workshop source, including its explicit End lines.

Variants



SetGlobalVariable

Fields

variable: String
value: Value


ModifyGlobalVariable

Fields

variable: String
value: Value


SetPlayerVariable

Fields

player: Value
variable: String
value: Value


ModifyPlayerVariable

Fields

player: Value
variable: String
value: Value


AssignMember

Fields

target: Value
value: Value


CallSubroutine

Fields

subroutine: String


If

Fields

condition: Value


ElseIf

Fields

condition: Value


Else



While

Fields

condition: Value


ForGlobalVariable

Fields

variable: String
start: Value
stop: Value
step: Value


ForPlayerVariable

Fields

player: Value
variable: String
start: Value
stop: Value
step: Value


End



Disabled

Fields

action: Box<Action>


Call

Fields

name: String
args: Vec<Value>

Implementations

Source

impl Action

pub fn disabled(action: Action) -> Self

pub fn call( name: impl Into<String>, args: impl IntoIterator<Item = Value>, ) -> Self