pub fn entries() -> impl Iterator<Item = &'static TableEntry>Expand description
Iterate the reviewed settings inventory with the hand-written projection taking precedence over the generated export projection. Duplicate paths are represented once in the semantic catalog while the parser and emitter continue to use the same lookup table.