Compatibility path for shared source and span types.
Structs
- Position
- A 1-based line/column position in a source file.
- Source
Comment - A source comment retained from the authored document.
- Source
Document - A source document retained independently from canonical semantic nodes.
- Source
Edit - A checked, byte-oriented source replacement.
- Source
File - One source file in the program’s file registry.
- Span
- A half-open, 1-based source interval in one file.
Enums
- Comment
Kind - Comment kinds currently supported by the raw Workshop source contract.
- Source
Edit Error - Failure while creating or applying source edits.
Type Aliases
- FileId
- A typed ID referencing a
SourceFilein the program’s file arena.